# Package for parsing the Swedish parlimentary proceedings
The proceedings can be found [here](https://github.com/welfare-state-analytics/riksdagen-corpus)

This can create a Pandas dataframe containing all speeches found, along with who spoke and when.

The usual way to use this method is in combination with Jupyter notebooks that are not included as part of this package.